def BannerStyleSerializer(style):
    return {
        'align_vertical': style.align_vertical,
        'align_horizontal': style.align_horizontal,
        'width': style.width,
        'height': style.height,
        'width_smallsize': style.width_smallsize,
        'height_smallsize': style.height_smallsize,
        'image_fit': style.image_fit,
    }


def BannerSerializer(banners):
    result = []

    for banner in banners:
        if banner.is_available():
            result.append({
                'id': banner.id,
                'name': banner.name,
                'image': banner.get_content(),
                'href': banner.href,
                'style': BannerStyleSerializer(banner.style)
            })

    return result



# Generated by Django 5.1.6 on 2025-05-30 02:46

import dj_banner.models
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='BannerStyle',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('align_vertical', models.CharField(choices=[('right', 'Right'), ('center', 'Center'), ('left', 'Left')], max_length=15)),
                ('align_horizontal', models.CharField(choices=[('top', 'Top'), ('middle', 'Middle'), ('bottom', 'Bottom')], max_length=15)),
                ('width', models.CharField(default='auto', help_text='You can set "auto" or percentage like "50%" or pixle like "200px" value', max_length=10)),
                ('height', models.CharField(default='auto', help_text='You can set "auto" or percentage like "50%" or pixle like "200px" value', max_length=10)),
                ('width_smallsize', models.CharField(default='auto', help_text='You can set "auto" or percentage like "50%" or pixle like "200px" value', max_length=10)),
                ('height_smallsize', models.CharField(default='auto', help_text='You can set "auto" or percentage like "50%" or pixle like "200px" value', max_length=10)),
                ('image_fit', models.CharField(choices=[('unset', 'Unset'), ('cover', 'Cover'), ('contain', 'Contain')], default='unset', max_length=10)),
            ],
        ),
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('url', models.TextField(help_text='Enter the address of the page where you want the banner to be displayed - (without domain address)')),
            ],
        ),
        migrations.CreateModel(
            name='Banner',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('image', models.ImageField(blank=True, null=True, upload_to=dj_banner.models.upload_image_banner)),
                ('image_url', models.URLField(blank=True, help_text='You can set image url instead image', null=True)),
                ('href', models.URLField(help_text='When it is clicked , it will be redirect to this address')),
                ('count_click', models.IntegerField(default=0)),
                ('style', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='dj_banner.bannerstyle')),
                ('pages', models.ManyToManyField(to='dj_banner.page')),
            ],
        ),
    ]



from django.db import models

import random, string


def random_string(len=18):
    return ''.join(random.choices(string.ascii_uppercase + string.ascii_lowercase + string.digits, k=len))


def upload_image_banner(instance, path):
    return f"dj_banner/images/{random_string(20)}/{random_string(7)}.{str(path).split('.')[-1]}"


class Page(models.Model):
    name = models.CharField(max_length=100)
    url = models.TextField(
        help_text='Enter the address of the page where you want the banner to be displayed - (without domain address)')

    def __str__(self):
        return self.name


class BannerStyle(models.Model):
    ALIGN_VERTICAL_OPTIONS = (
        ('right', 'Right'),
        ('center', 'Center'),
        ('left', 'Left'),
    )

    ALIGN_HORIZONTAL_OPTIONS = (
        ('top', 'Top'),
        ('middle', 'Middle'),
        ('bottom', 'Bottom'),
    )

    IMAGE_FIT_OPTIONS = (
        ('unset', 'Unset'),
        ('cover', 'Cover'),
        ('contain', 'Contain'),
    )

    name = models.CharField(max_length=100)
    align_vertical = models.CharField(max_length=15, choices=ALIGN_VERTICAL_OPTIONS)
    align_horizontal = models.CharField(max_length=15, choices=ALIGN_HORIZONTAL_OPTIONS)
    width = models.CharField(max_length=10, default='auto',
                             help_text='You can set "auto" or percentage like "50%" or pixle like "200px" value')
    height = models.CharField(max_length=10, default='auto',
                              help_text='You can set "auto" or percentage like "50%" or pixle like "200px" value')
    width_smallsize = models.CharField(max_length=10, default='auto',
                                       help_text='You can set "auto" or percentage like "50%" or pixle like "200px" value')
    height_smallsize = models.CharField(max_length=10, default='auto',
                                        help_text='You can set "auto" or percentage like "50%" or pixle like "200px" value')
    image_fit = models.CharField(max_length=10, default='unset', choices=IMAGE_FIT_OPTIONS)

    def __str__(self):
        return self.name


class Banner(models.Model):
    name = models.CharField(max_length=100)
    style = models.ForeignKey(BannerStyle, on_delete=models.CASCADE)
    pages = models.ManyToManyField(Page)
    image = models.ImageField(upload_to=upload_image_banner, null=True, blank=True)
    image_url = models.URLField(null=True, blank=True, help_text='You can set image url instead image')
    href = models.URLField(help_text='When it is clicked , it will be redirect to this address')
    count_click = models.IntegerField(default=0)

    def __str__(self):
        return self.name

    def get_content(self):
        image = self.image or None
        if not image:
            image = self.image_url
        else:
            image = image.url
        return image

    def is_available(self):
        return True if self.get_content() is not None else False



import json

from django.http import JsonResponse
from django.views.decorators.csrf import csrf_exempt

from . import models, serializers


@csrf_exempt
def index(request):
    try:
        data = json.loads(request.body)
    except:
        data = request.data

    context = {}
    url = data.get('url')
    page = models.Page.objects.filter(url=url).last()
    if page:
        status_code = 200
        context = {
            'banners': serializers.BannerSerializer(page.banner_set.all())
        }
    else:
        status_code = 404

    context['status'] = status_code
    return JsonResponse(context)


@csrf_exempt
def banner_click(request):
    try:
        data = json.loads(request.body)
    except:
        data = request.data

    banner_id = data.get('banner_id') or 0
    banner = models.Banner.objects.filter(id=banner_id).first()
    if banner:
        banner.count_click += 1
        banner.save()
    return JsonResponse({})





from setuptools import setup, find_packages

setup(
    name='dj_banner',
    version='1.0.0',
    description='slick Banner Ads for Django',
    long_description=open('README.md', encoding='utf8').read(),
    long_description_content_type='text/markdown',
    include_package_data=True,
    url='https://github.com/FZl47/dj_banner',
    author='FZl47',
    author_email='fzl8747@gmail.com',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
